@@ -54,7 +54,7 @@ Kwave::MP3Encoder::MP3Encoder()
     :Kwave::Encoder(),
      m_property_map(),
      m_lock(),
-     m_dst(Q_NULLPTR),
+     m_dst(nullptr),
      m_process(this),
      m_program(),
      m_params()
@@ -194,7 +194,7 @@ void Kwave::MP3Encoder::encodeID3Tags(const Kwave::MetaDataList &meta_data,
                     field->Set(static_cast<const unicode_t *>(str_val.utf16()));
                 } else {
                     delete frame;
-                    frame = Q_NULLPTR;
+                    frame = nullptr;
                 }
                 break;
             }
@@ -228,7 +228,7 @@ void Kwave::MP3Encoder::encodeID3Tags(const Kwave::MetaDataList &meta_data,
                     qWarning("MP3Encoder::encodeID3Tags(): invalid date: '%s'",
                              DBG(str_val));
                     delete frame;
-                    frame = Q_NULLPTR;
+                    frame = nullptr;
                 }
                 break;
             }
@@ -242,7 +242,7 @@ void Kwave::MP3Encoder::encodeID3Tags(const Kwave::MetaDataList &meta_data,
             default:
                 // ignore
                 delete frame;
-                frame = Q_NULLPTR;
+                frame = nullptr;
                 break;
         }
 
@@ -453,7 +453,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 
         unsigned int written = 0;
         for (written = 0; written < count; written++) {
-            const sample_t *src_buf = Q_NULLPTR;
+            const sample_t *src_buf = nullptr;
 
             // fill input buffer with samples
             for (x = 0; x < tracks; ++x) {
@@ -560,7 +560,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 
     {
         QMutexLocker _lock(&m_lock);
-        m_dst = Q_NULLPTR;
+        m_dst = nullptr;
         dst.close();
     }
 
@@ -581,3 +581,5 @@ void Kwave::MP3Encoder::dataAvailable()
 
 /***************************************************************************/
 /***************************************************************************/
+
+#include "moc_MP3Encoder.cpp"
