@@ -67,7 +67,7 @@ namespace Kwave
         );
 
         /** Destructor */
-        virtual ~K3BExportDialog();
+        virtual ~K3BExportDialog() override;
 
         /** returns the title/artist detection pattern (as is, not escaped) */
         QString pattern() const;
