@@ -60,8 +60,10 @@
 #include "KeywordWidget.h"
 #include "SelectDateDialog.h"
 
+using namespace Qt::StringLiterals;
+
 /** section in the config file for storing default settings */
-#define CONFIG_DEFAULT_SECTION "plugin fileinfo - setup dialog"
+#define CONFIG_DEFAULT_SECTION u"plugin fileinfo - setup dialog"_s
 
 //***************************************************************************
 Kwave::FileInfoDialog::FileInfoDialog(QWidget *parent, Kwave::FileInfo &info)
@@ -500,7 +502,7 @@ void Kwave::FileInfoDialog::setupSourceTab()
         QVariant(m_info.get(Kwave::INF_CD)).toInt() : 0;
     sbCD->setValue(cd);
 
-    initInfo(Q_NULLPTR, sbCDs, Kwave::INF_CDS);
+    initInfo(nullptr, sbCDs, Kwave::INF_CDS);
     int cds = (m_info.contains(Kwave::INF_CDS)) ?
         QVariant(m_info.get(Kwave::INF_CDS)).toInt() : 0;
     sbCDs->setValue(cds);
@@ -510,7 +512,7 @@ void Kwave::FileInfoDialog::setupSourceTab()
         QVariant(m_info.get(Kwave::INF_TRACK)).toInt() : 0;
     sbTrack->setValue(track);
 
-    initInfo(Q_NULLPTR, sbTracks, Kwave::INF_TRACKS);
+    initInfo(nullptr, sbTracks, Kwave::INF_TRACKS);
     int tracks = (m_info.contains(Kwave::INF_TRACKS)) ?
         QVariant(m_info.get(Kwave::INF_TRACKS)).toInt() : 0;
     sbTracks->setValue(tracks);
@@ -755,6 +757,7 @@ void Kwave::FileInfoDialog::mpegLayerChanged()
         case 3:
             compression = Kwave::Compression::MPEG_LAYER_III;
             break;
+        DEFAULT_IGNORE;
     }
 
     if (compression != Kwave::Compression::NONE) {
@@ -1062,6 +1065,7 @@ void Kwave::FileInfoDialog::accept()
                 m_info.set(Kwave::INF_VBR_QUALITY, QVariant(quality));
                 break;
             }
+            DEFAULT_IMPOSSIBLE;
         }
     }
 
@@ -1130,3 +1134,5 @@ void Kwave::FileInfoDialog::invokeHelp()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_FileInfoDialog.cpp"
