@@ -82,14 +82,14 @@ Kwave::PlayBackPulseAudio::PlayBackPulseAudio(const Kwave::FileInfo &info)
      m_info(info),
      m_rate(0),
      m_bytes_per_sample(0),
-     m_buffer(Q_NULLPTR),
+     m_buffer(nullptr),
      m_buffer_size(0),
      m_buffer_used(0),
      m_bufbase(10),
-     m_pa_proplist(Q_NULLPTR),
-     m_pa_mainloop(Q_NULLPTR),
-     m_pa_context(Q_NULLPTR),
-     m_pa_stream(Q_NULLPTR),
+     m_pa_proplist(nullptr),
+     m_pa_mainloop(nullptr),
+     m_pa_context(nullptr),
+     m_pa_stream(nullptr),
      m_device_list()
 {
 }
@@ -180,6 +180,7 @@ void Kwave::PlayBackPulseAudio::notifyContext(pa_context *c)
             qWarning("PlayBackPulseAudio: PA_CONTEXT_FAILED");
             m_mainloop_signal.wakeAll();
             break;
+        DEFAULT_IGNORE;
     }
 }
 
@@ -257,6 +258,7 @@ void Kwave::PlayBackPulseAudio::notifyStreamState(pa_stream* stream)
         case PA_STREAM_TERMINATED:
             m_mainloop_signal.wakeAll();
             break;
+        DEFAULT_IGNORE;
     }
 }
 
@@ -364,9 +366,9 @@ bool Kwave::PlayBackPulseAudio::connectToServer()
     bool failed = false;
     int error = pa_context_connect(
         m_pa_context,                       // context
-        Q_NULLPTR,                          // server
+        nullptr,                          // server
         static_cast<pa_context_flags_t>(0), // flags
-        Q_NULLPTR                           // API
+        nullptr                           // API
     );
     if (error < 0)
     {
@@ -423,20 +425,20 @@ void Kwave::PlayBackPulseAudio::disconnectFromServer()
     if (m_pa_context) {
         pa_context_disconnect(m_pa_context);
         pa_context_unref(m_pa_context);
-        m_pa_context = Q_NULLPTR;
+        m_pa_context = nullptr;
     }
 
     // stop and free the main loop
     if (m_pa_mainloop) {
         pa_mainloop_free(m_pa_mainloop);
-        m_pa_mainloop = Q_NULLPTR;
+        m_pa_mainloop = nullptr;
         qDebug("PlayBackPulseAudio: mainloop freed");
     }
 
     // release the property list
     if (m_pa_proplist) {
         pa_proplist_free(m_pa_proplist);
-        m_pa_proplist = Q_NULLPTR;
+        m_pa_proplist = nullptr;
     }
 
 }
@@ -481,7 +483,7 @@ QString Kwave::PlayBackPulseAudio::open(const QString &device, double rate,
     // determine the buffer size
     m_bytes_per_sample = sizeof(sample_t) * channels;
     m_buffer_size      = 0;
-    m_buffer           = Q_NULLPTR;
+    m_buffer           = nullptr;
     m_bufbase          = bufbase;
 
     // build a property list for the stream
@@ -527,7 +529,7 @@ QString Kwave::PlayBackPulseAudio::open(const QString &device, double rate,
         m_pa_context,
         name.toUtf8().data(),
         &sample_spec,
-        Q_NULLPTR /* const pa_channel_map *map */,
+        nullptr /* const pa_channel_map *map */,
         _proplist);
     pa_proplist_free(_proplist);
 
@@ -557,13 +559,13 @@ QString Kwave::PlayBackPulseAudio::open(const QString &device, double rate,
     // connect the stream in playback mode
     int result = pa_stream_connect_playback(
         m_pa_stream,
-        pa_device.length() ? pa_device.toUtf8().data() : Q_NULLPTR,
+        pa_device.length() ? pa_device.toUtf8().data() : nullptr,
         &attr /* buffer attributes */,
         static_cast<pa_stream_flags_t>(
             PA_STREAM_INTERPOLATE_TIMING |
             PA_STREAM_AUTO_TIMING_UPDATE),
-        Q_NULLPTR /* volume */,
-        Q_NULLPTR /* sync stream */ );
+        nullptr /* volume */,
+        nullptr /* sync stream */ );
 
     if (result >= 0) {
         m_mainloop_signal.wait(&m_mainloop_lock, TIMEOUT_CONNECT_PLAYBACK);
@@ -574,7 +576,7 @@ QString Kwave::PlayBackPulseAudio::open(const QString &device, double rate,
 
     if (result < 0) {
         pa_stream_unref(m_pa_stream);
-        m_pa_stream = Q_NULLPTR;
+        m_pa_stream = nullptr;
         return i18n("Failed to open a PulseAudio stream for playback (%1).",
                     QString::fromLocal8Bit(
                     pa_strerror(pa_context_errno(m_pa_context))));
@@ -684,7 +686,7 @@ int Kwave::PlayBackPulseAudio::flush()
                 m_pa_stream,
                 buffer_ptr,
                 len,
-                Q_NULLPTR,
+                nullptr,
                 0,
                 PA_SEEK_RELATIVE
         );
@@ -703,7 +705,7 @@ int Kwave::PlayBackPulseAudio::flush()
 
     // buffer is written out now
     m_buffer_used = 0;
-    m_buffer      = Q_NULLPTR;
+    m_buffer      = nullptr;
 
     return result;
 }
@@ -713,7 +715,7 @@ void Kwave::PlayBackPulseAudio::run_wrapper(const QVariant &params)
 {
     Q_UNUSED(params)
     m_mainloop_lock.lock();
-    pa_mainloop_run(m_pa_mainloop, Q_NULLPTR);
+    pa_mainloop_run(m_pa_mainloop, nullptr);
     m_mainloop_lock.unlock();
 }
 
@@ -729,7 +731,7 @@ int Kwave::PlayBackPulseAudio::close()
     // release the allocated memory
     if (m_buffer) {
         free(m_buffer);
-        m_buffer = Q_NULLPTR;
+        m_buffer = nullptr;
     }
 
     if (m_pa_mainloop && m_pa_stream) {
@@ -769,7 +771,7 @@ int Kwave::PlayBackPulseAudio::close()
         if (m_pa_stream) {
             pa_stream_disconnect(m_pa_stream);
             pa_stream_unref(m_pa_stream);
-            m_pa_stream = Q_NULLPTR;
+            m_pa_stream = nullptr;
         }
     }
 
