@@ -61,7 +61,7 @@ Kwave::PlayBackDialog::PlayBackDialog(
 )
     :QDialog(p.parentWidget()), PlayBackDlg(),
      m_playback_controller(playback_controller),
-     m_device(Q_NULLPTR),
+     m_device(nullptr),
      m_playback_params(params),
      m_methods_map(),
      m_file_filter(_("")),
@@ -80,15 +80,15 @@ Kwave::PlayBackDialog::PlayBackDialog(
     }
     cbMethod->setEnabled(cbMethod->count() > 1);
 
-    connect(cbMethod, SIGNAL(activated(int)),
-            SLOT(methodSelected(int)));
+    connect(cbMethod, &KComboBox::currentIndexChanged,
+            this, &PlayBackDialog::methodSelected);
     connect(cbDevice, SIGNAL(editTextChanged(QString)),
             SLOT(setDevice(QString)));
-    connect(cbDevice, SIGNAL(activated(QString)),
+    connect(cbDevice, SIGNAL(textActivated(QString)),
             SLOT(setDevice(QString)));
     connect(cbBitsPerSample, SIGNAL(editTextChanged(QString)),
             SLOT(bitsPerSampleSelected(QString)));
-    connect(cbBitsPerSample, SIGNAL(activated(QString)),
+    connect(cbBitsPerSample, SIGNAL(textActivated(QString)),
             SLOT(bitsPerSampleSelected(QString)));
     connect(sbChannels, SIGNAL(valueChanged(int)),
             SLOT(setChannels(int)));
@@ -117,12 +117,8 @@ Kwave::PlayBackDialog::PlayBackDialog(
     setFixedHeight(sizeHint().height());
 
     // update the GUI elements
-    // order is: Method -> Device -> "Select..."-button
-    // -> Channels -> Bits per Sample
+    // set Method, which will set Device, Channels, and Bits per Sample
     setMethod(params.method);
-    setDevice(params.device);
-    setBitsPerSample(params.bits_per_sample);
-    setChannels(params.channels);
 
     // buffer size is independent
     setBufferSize(params.bufbase);
@@ -144,22 +140,28 @@ void Kwave::PlayBackDialog::setMethod(Kwave::playback_method_t method)
     m_playback_params.method = method;
 
     // update the selection in the combo box if necessary
+    // initial call will be with method == Kwave::PLAYBACK_NONE
+    // we want to get a valid method set before updating the combo box
+    // we will get called again when the valid method gets set later
     int index = cbMethod->findData(static_cast<int>(method));
-    if (cbMethod->currentIndex() != index) {
+    if ((cbMethod->currentIndex() != index) && (method != Kwave::PLAYBACK_NONE)) {
         cbMethod->setCurrentIndex(index);
         return; // we will get called again, through "methodSelected(...)"
     }
 
+    QString name = (method == Kwave::PLAYBACK_NONE) ?
+                    QStringLiteral("none") :
+                    m_methods_map.name(m_methods_map.findFromData(method));
     qDebug("PlayBackDialog::setMethod('%s' [%d])",
-           DBG(m_methods_map.name(m_methods_map.findFromData(method))),
+           DBG(name),
            static_cast<int>(method) );
 
     // set hourglass cursor
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     // change the playback method (class PlayBackDevice)
-    if (m_device) delete m_device;
-    m_device = Q_NULLPTR;
+    delete m_device;
+    m_device = nullptr;
 
     // remember the device selection, just for the GUI
     // for the next time this method gets selected
@@ -168,15 +170,17 @@ void Kwave::PlayBackDialog::setMethod(Kwave::playback_method_t method)
     QString section = _("plugin playback");
     KConfigGroup cfg = KSharedConfig::openConfig()->group(section);
 
-    // save the current device
-    cfg.writeEntry(
-        QString(_("last_device_%1")).arg(static_cast<int>(old_method)),
-        m_playback_params.device);
-    qDebug("SAVE:    '%s' (%d) -> '%s'",
-            DBG(m_methods_map.name(m_methods_map.findFromData(old_method))),
-            static_cast<int>(old_method),
-            DBG(m_playback_params.device.split(_("|")).at(0)));
-    cfg.sync();
+    if (method != Kwave::PLAYBACK_NONE) {
+        // save the current device
+        cfg.writeEntry(
+            QString(_("last_device_%1")).arg(static_cast<int>(old_method)),
+            m_playback_params.device);
+        qDebug("SAVE:    '%s' (%d) -> '%s'",
+                DBG(m_methods_map.name(m_methods_map.findFromData(old_method))),
+                static_cast<int>(old_method),
+                DBG(m_playback_params.device.split(_("|")).at(0)));
+        cfg.sync();
+    }
 
     // NOTE: the "method" may get modified here if not supported!
     m_playback_controller.checkMethod(method);
@@ -300,16 +304,16 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 
         // build a tree with all nodes in the list
         foreach (const QString &dev_id, devices) {
-            QTreeWidgetItem *parent = Q_NULLPTR;
+            QTreeWidgetItem *parent = nullptr;
 
             QStringList list = dev_id.split(_("||"), Qt::KeepEmptyParts);
             foreach (const QString &t, list) {
                 QString token(t);
-                QTreeWidgetItem *item = Q_NULLPTR;
+                QTreeWidgetItem *item = nullptr;
 
                 // split the icon name from the token
                 QString icon_name;
-                int pos = token.indexOf(QLatin1Char('|'));
+                qsizetype pos = token.indexOf(QLatin1Char('|'));
                 if (pos > 0) {
                     icon_name = token.mid(pos+1);
                     token     = token.left(pos);
@@ -441,7 +445,7 @@ void Kwave::PlayBackDialog::setDevice(const QString &device)
 
     if (listDevices->isEnabled()) {
         // treeview mode
-        QTreeWidgetItem *node = m_devices_list_map.key(device, Q_NULLPTR);
+        QTreeWidgetItem *node = m_devices_list_map.key(device, nullptr);
         if (node) {
             node->setSelected(true);
             listDevices->scrollToItem(node);
@@ -665,3 +669,5 @@ void Kwave::PlayBackDialog::invokeHelp()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_PlayBackDialog.cpp"
